@@ -1,4 +1,4 @@
-/* $Id: addon_management.cpp 33405 2009-03-08 00:35:27Z shadowmaster $ */
+/* $Id: addon_management.cpp 35863 2009-05-24 09:54:22Z soliton $ */
 /*
    Copyright (C) 2003 - 2008 by David White <dave@whitevine.net>
                  2008 - 2009 by Ignacio R. Morelle <shadowm2006@gmail.com>
@@ -450,7 +450,7 @@ namespace {
 												count_missing);
 			/* GCC-3.3 needs a temp var otherwise compilation fails */
 			gui::dialog dlg(disp, msg_title, msg_entrytxt + "\n" + missing +
-			                "\n" + _("Do you still want to download it?"), gui::OK_CANCEL);
+			                "\n" + _("Do you want to download this add-on? (You will still have to install the dependencies in order to play.)"), gui::OK_CANCEL);
 			if (dlg.show())
 				return false;
 		}
