@@ -1,6 +1,6 @@
-/* $Id: playsingle_controller.hpp 23842 2008-02-16 08:47:16Z mordante $ */
+/* $Id: playsingle_controller.hpp 31859 2009-01-01 10:28:26Z mordante $ */
 /*
-   Copyright (C) 2006 - 2008 by Joerg Hinrichs <joerg.hinrichs@alice-dsl.de>
+   Copyright (C) 2006 - 2009 by Joerg Hinrichs <joerg.hinrichs@alice-dsl.de>
    wesnoth playlevel Copyright (C) 2003 by David White <dave@whitevine.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
@@ -19,7 +19,7 @@
 #include "global.hpp"
 
 #include "cursor.hpp"
-#include "menu_events.hpp"
+#include "game_end_exceptions.hpp"
 #include "play_controller.hpp"
 
 struct upload_log;
@@ -29,10 +29,11 @@ struct upload_log;
 class playsingle_controller : public play_controller
 {
 public:
-	playsingle_controller(const config& level, const game_data& gameinfo, game_state& state_of_game,
+	playsingle_controller(const config& level, game_state& state_of_game,
 		const int ticks, const int num_turns, const config& game_config, CVideo& video, bool skip_replay);
+        virtual ~playsingle_controller() ;
 
-	LEVEL_RESULT play_scenario(const std::vector<config*>& story, upload_log& log, bool skip_replay);
+	LEVEL_RESULT play_scenario(const std::vector<config*>& story, upload_log& log, bool skip_replay, end_level_exception* end_level = NULL);
 
 	virtual void handle_generic_event(const std::string& name);
 
@@ -51,6 +52,8 @@ public:
 	virtual void unit_hold_position();
 	virtual void end_unit_turn();
 	virtual void user_command();
+	virtual void custom_command();
+	virtual void ai_formula();
 	virtual void clear_messages();
 #ifdef USRCMD2
 	virtual void user_command_2();
@@ -62,6 +65,8 @@ protected:
 	virtual void play_turn(bool no_save);
 	virtual void play_side(const unsigned int team_index, bool save);
 	virtual void before_human_turn(bool save);
+	void show_turn_dialog();
+	void execute_gotos();
 	virtual void play_human_turn();
 	virtual void after_human_turn();
 	void end_turn_record();
@@ -78,13 +83,17 @@ protected:
 	bool end_turn_;
 	bool player_type_changed_;
 	bool replaying_;
-private:
 	bool turn_over_;
+	bool skip_next_turn_;
+private:
 	void report_victory(std::stringstream& report,
 		    end_level_exception& end_level,
 		    int player_gold,
-		    int remaining_gold, int finishing_bonus_per_turn, 
+		    int remaining_gold, int finishing_bonus_per_turn,
 		    int turns_left, int finishing_bonus);
+
+	std::vector<std::string> victory_music_;
+	std::vector<std::string> defeat_music_;
 };
 
 
