@@ -1,6 +1,6 @@
-/* $Id: textbox.cpp 23842 2008-02-16 08:47:16Z mordante $ */
+/* $Id: textbox.cpp 33261 2009-03-01 18:12:59Z silene $ */
 /*
-   Copyright (C) 2003 - 2008 by David White <dave@whitevine.net>
+   Copyright (C) 2003 - 2009 by David White <dave@whitevine.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -12,23 +12,16 @@
    See the COPYING file for more details.
 */
 
+#define GETTEXT_DOMAIN "wesnoth-lib"
+
 #include "global.hpp"
 
 #include "widgets/textbox.hpp"
 #include "clipboard.hpp"
-#include "font.hpp"
-#include "language.hpp"
 #include "log.hpp"
-#include "sdl_utils.hpp"
-#include "serialization/string_utils.hpp"
-#include "util.hpp"
 #include "video.hpp"
 
-#include "SDL.h"
 
-#include <algorithm>
-#include <cctype>
-#include <cstring>
 
 #define WRN_DISPLAY LOG_STREAM(warn, display)
 #define DBG_G LOG_STREAM(debug, general)
@@ -63,6 +56,9 @@ textbox::~textbox()
 void textbox::set_inner_location(SDL_Rect const &rect)
 {
 	bg_register(rect);
+	if (text_image_.null()) return;
+	text_pos_ = 0;
+	update_text_cache(false);
 }
 
 const std::string textbox::text() const
@@ -72,7 +68,7 @@ const std::string textbox::text() const
 }
 
 // set_text does not respect max_size_
-void textbox::set_text(const std::string& text)
+void textbox::set_text(const std::string& text, const SDL_Color& color)
 {
 	text_ = utils::string_to_wstring(text);
 	cursor_ = text_.size();
@@ -80,14 +76,14 @@ void textbox::set_text(const std::string& text)
 	selstart_ = -1;
 	selend_ = -1;
 	set_dirty(true);
-	update_text_cache(true);
+	update_text_cache(true, color);
 	handle_text_changed(text_);
 }
 
-void textbox::append_text(const std::string& text, bool auto_scroll)
+void textbox::append_text(const std::string& text, bool auto_scroll, const SDL_Color& color)
 {
 	if(text_image_.get() == NULL) {
-		set_text(text);
+		set_text(text, color);
 		return;
 	}
 
@@ -98,8 +94,8 @@ void textbox::append_text(const std::string& text, bool auto_scroll)
 	const bool is_at_bottom = get_position() == get_max_position();
 	const wide_string& wtext = utils::string_to_wstring(text);
 
-	const surface new_text = add_text_line(wtext);
-	const surface new_surface = create_compatible_surface(text_image_,maximum<size_t>(text_image_->w,new_text->w),text_image_->h+new_text->h);
+	const surface new_text = add_text_line(wtext, color);
+	const surface new_surface = create_compatible_surface(text_image_,std::max<size_t>(text_image_->w,new_text->w),text_image_->h+new_text->h);
 
 	SDL_SetAlpha(new_text.get(),0,0);
 	SDL_SetAlpha(text_image_.get(),0,0);
@@ -157,8 +153,8 @@ void textbox::draw_contents()
 
 	if(text_image_ != NULL) {
 		src.y = yscroll_;
-		src.w = minimum<size_t>(loc.w,text_image_->w);
-		src.h = minimum<size_t>(loc.h,text_image_->h);
+		src.w = std::min<size_t>(loc.w,text_image_->w);
+		src.h = std::min<size_t>(loc.h,text_image_->h);
 		src.x = text_pos_;
 		SDL_Rect dest = screen_area();
 		dest.x = loc.x;
@@ -166,8 +162,8 @@ void textbox::draw_contents()
 
 		// Fills the selected area
 		if(is_selection()) {
-			const int start = minimum<int>(selstart_,selend_);
-			const int end = maximum<int>(selstart_,selend_);
+			const int start = std::min<int>(selstart_,selend_);
+			const int end = std::max<int>(selstart_,selend_);
 			int startx = char_x_[start];
 			int starty = char_y_[start];
 			const int endx = char_x_[end];
@@ -242,21 +238,13 @@ void textbox::set_wrap(bool val)
 	}
 }
 
-void textbox::set_location(const SDL_Rect& rect)
-{
-	text_pos_ = 0;
-
-	scrollarea::set_location(rect);
-	set_shown_size(location().h);
-}
-
 void textbox::scroll(unsigned int pos)
 {
 	yscroll_ = pos;
 	set_dirty(true);
 }
 
-surface textbox::add_text_line(const wide_string& text)
+surface textbox::add_text_line(const wide_string& text, const SDL_Color& color)
 {
 	line_height_ = font::get_max_height(font_size);
 
@@ -316,19 +304,19 @@ surface textbox::add_text_line(const wide_string& text)
 	}
 
 	const std::string s = utils::wstring_to_string(wrapped_text);
-	const surface res(font::get_rendered_text(s, font_size, font::NORMAL_COLOUR));
+	const surface res(font::get_rendered_text(s, font_size, color));
 
 	return res;
 }
 
 
-void textbox::update_text_cache(bool changed)
+void textbox::update_text_cache(bool changed, const SDL_Color& color)
 {
 	if(changed) {
 		char_x_.clear();
 		char_y_.clear();
 
-		text_image_.assign(add_text_line(text_));
+		text_image_.assign(add_text_line(text_, color));
 	}
 
 	int cursor_x = char_x_[cursor_];
@@ -356,9 +344,9 @@ void textbox::erase_selection()
 	if(!is_selection())
 		return;
 
-	wide_string::iterator itor = text_.begin() + minimum(selstart_, selend_);
+	wide_string::iterator itor = text_.begin() + std::min(selstart_, selend_);
 	text_.erase(itor, itor + abs(selend_ - selstart_));
-	cursor_ = minimum(selstart_, selend_);
+	cursor_ = std::min(selstart_, selend_);
 	selstart_ = selend_ = -1;
 }
 
@@ -425,13 +413,13 @@ void textbox::handle_event(const SDL_Event& event)
 	}
 
 	SDL_Rect const &loc = inner_location();
-	bool clicked_inside = (event.type == SDL_MOUSEBUTTONDOWN
+	bool clicked_inside = !mouse_locked() && (event.type == SDL_MOUSEBUTTONDOWN
 					   && (mousebuttons & SDL_BUTTON(1))
 					   && point_in_rect(mousex, mousey, loc));
 	if(clicked_inside) {
 		set_focus(true);
 	}
-	if ((grabmouse_ && (event.type == SDL_MOUSEMOTION)) || clicked_inside) {
+	if ((grabmouse_ && (!mouse_locked() && event.type == SDL_MOUSEMOTION)) || clicked_inside) {
 		const int x = mousex - loc.x + text_pos_;
 		const int y = mousey - loc.y;
 		int pos = 0;
@@ -474,7 +462,7 @@ void textbox::handle_event(const SDL_Event& event)
 	//if we don't have the focus, then see if we gain the focus,
 	//otherwise return
 	if(focus(&event) == false) {
-		if (event.type == SDL_MOUSEMOTION && point_in_rect(mousex, mousey, loc))
+		if (!mouse_locked() && event.type == SDL_MOUSEMOTION && point_in_rect(mousex, mousey, loc))
 			events::focus_handler(this);
 
 		return;
@@ -543,9 +531,9 @@ void textbox::handle_event(const SDL_Event& event)
 	if(!(c == SDLK_UP || c == SDLK_DOWN || c == SDLK_LEFT || c == SDLK_RIGHT ||
 	   c == SDLK_DELETE || c == SDLK_BACKSPACE || c == SDLK_END || c == SDLK_HOME ||
 	   c == SDLK_PAGEUP || c == SDLK_PAGEDOWN)) {
-		if(character != 0)
+		if(character != 0) {
 			DBG_G << "Char: " << character << ", c = " << c << "\n";
-
+		}
 		if(event.key.keysym.mod & copypaste_modifier) {
 			switch(c) {
 			case SDLK_v: // paste
@@ -554,7 +542,7 @@ void textbox::handle_event(const SDL_Event& event)
 				if(is_selection())
 					erase_selection();
 
-				std::string str = copy_from_clipboard();
+				std::string str = copy_from_clipboard(false);
 
 				//cut off anything after the first newline
 				str.erase(std::find_if(str.begin(),str.end(),utils::isnewline),str.end());
@@ -575,12 +563,12 @@ void textbox::handle_event(const SDL_Event& event)
 
 			case SDLK_c: // copy
 				{
-				const size_t beg = minimum<size_t>(size_t(selstart_),size_t(selend_));
-				const size_t end = maximum<size_t>(size_t(selstart_),size_t(selend_));
+				const size_t beg = std::min<size_t>(size_t(selstart_),size_t(selend_));
+				const size_t end = std::max<size_t>(size_t(selstart_),size_t(selend_));
 
 				wide_string ws = wide_string(text_.begin() + beg, text_.begin() + end);
 				std::string s = utils::wstring_to_string(ws);
-				copy_to_clipboard(s);
+				copy_to_clipboard(s, false);
 				}
 				break;
 			}
